import { Lang, Theme, HighlighterOptions, Highlighter } from 'shiki';

declare const defaultCode: {
    abap: string;
    "actionscript-3": string;
    ada: string;
    apache: string;
    apex: string;
    apl: string;
    applescript: string;
    ara: string;
    astro: string;
    awk: string;
    ballerina: string;
    batch: string;
    berry: string;
    bicep: string;
    blade: string;
    cadence: string;
    clarity: string;
    clojure: string;
    cmake: string;
    asm: string;
    c: string;
    cobol: string;
    coffee: string;
    crystal: string;
    css: string;
    cue: string;
    d: string;
    dart: string;
    dax: string;
    dockerfile: string;
    "dream-maker": string;
    elixir: string;
    elm: string;
    erb: string;
    erlang: string;
    fish: string;
    "f#": string;
    "git-commit": string;
    glsl: string;
    gnuplot: string;
    graphql: string;
    groovy: string;
    hack: string;
    haml: string;
    handlebars: string;
    haskell: string;
    hcl: string;
    hlsl: string;
    html: string;
    cpp: string;
    "c#": string;
    go: string;
    java: string;
    javascript: string;
    imba: string;
    ini: string;
    properties: string;
    jison: string;
    json: string;
    json5: string;
    jsonc: string;
    jsonnet: string;
    jssm: string;
    jsx: string;
    kotlin: string;
    kusto: string;
    kql: string;
    julia: string;
    matlab: string;
    latex: string;
    less: string;
    liquid: string;
    php: string;
    lisp: string;
    logo: string;
    lua: string;
    make: string;
    makefile: string;
    markdown: string;
    marko: string;
    mdx: string;
    mermaid: string;
    nginx: string;
    nim: string;
    nix: string;
    objc: string;
    ocaml: string;
    pascal: string;
    perl: string;
    powerquery: string;
    powershell: string;
    prisma: string;
    prolog: string;
    proto: string;
    plsql: string;
    purescript: string;
    raku: string;
    perl6: string;
    razor: string;
    reg: string;
    rel: string;
    riscv: string;
    sas: string;
    sass: string;
    scala: string;
    scheme: string;
    shaderlab: string;
    scss: string;
    shader: string;
    shellscript: string;
    bash: string;
    shell: string;
    zsh: string;
    smalltalk: string;
    solidity: string;
    r: string;
    sparql: string;
    "ssh-config": string;
    stata: string;
    stylus: string;
    svelte: string;
    python: string;
    ruby: string;
    rust: string;
    sql: string;
    "system-verilog": string;
    tcl: string;
    tex: string;
    toml: string;
    tsx: string;
    turtle: string;
    swift: string;
    twig: string;
    typescript: string;
    vb: string;
    verilog: string;
    vhdl: string;
    viml: string;
    vimscript: string;
    vue: string;
    wasm: string;
    wenyan: string;
    wgsl: string;
    wolfram: string;
    xml: string;
    xsl: string;
    yaml: string;
    zenscript: string;
};
declare const supportedLangs: string[];

type StringLiteralUnion<T extends U, U = string> = T | (U & {});
interface CodeToShakuHtmlOptions {
    /**
     * by default Shaku syntax is supported
     * you can disable shaku syntax by this flag
     * then it just renders as normal shiki
     */
    isShakuSyntaxEnabled?: boolean;
    lang?: StringLiteralUnion<Lang>;
    theme?: StringLiteralUnion<Theme>;
    /**
     * whether or not to escape the annotation
     * @default false
     */
    useDangerousRawHtml?: boolean;
    /**
     * by default shaku doesn't parse the markdown
     * you can pass your own parser with `useDangerousRawHtml: false`
     * do remember to sanitize
     */
    markdownToHtmlAndSanitize?: (md: string) => string;
}
declare let codeToShakuHtml: (this: ShakuHighlighter, { code, options, }: {
    code: string;
    options?: CodeToShakuHtmlOptions | undefined;
}) => {
    skipped: boolean;
    html: string;
};

interface ShakuHighlighter extends Highlighter {
    codeToShakuHtml: typeof codeToShakuHtml;
    fallbackToShiki?: boolean;
}
type ShakuHighlighterOptions = HighlighterOptions & {
    fallbackToShiki?: boolean;
};
declare function getShakuHighlighters(options: ShakuHighlighterOptions): Promise<ShakuHighlighter[]>;

export { ShakuHighlighterOptions, defaultCode, getShakuHighlighters, supportedLangs };
